@@ -3,7 +3,7 @@
 
  Lincoln Stein <lincoln.stein@gmail.com>
  Ben Faga <ben.faga@gmail.com>
- $Id: controller.js 22339 2009-12-08 19:04:34Z lstein $
+ $Id: controller.js 22464 2009-12-23 21:00:15Z lstein $
 
 Indentation courtesy of Emacs javascript-mode 
 (http://mihai.bazon.net/projects/emacs-javascript-mode/javascript.el)
@@ -23,12 +23,10 @@ Method structure
 
 //  Element Names
 var track_listing_id        = 'tracks_panel'; 
-var external_listing_id     = 'upload_tracks_panel'; 
 var overview_container_id   = 'overview_panels'; 
 var region_container_id     = 'region_panels'; 
 var detail_container_id     = 'detail_panels'; 
 var external_utility_div_id = 'external_utility_div'; 
-var edit_upload_form_id     = 'edit_upload_form';
 var page_title_id           = 'page_title';
 var galaxy_form_id          = 'galaxy_form';
 var visible_span_id         = 'span';
@@ -468,7 +466,7 @@ var GBrowseController = Class.create({
          parameters: {
            action:          'rerender_track',
            track_id:        gbtrack.track_id,
-	   nocache:         nocache
+	   nocache:         nocache ? 1 : 0
          },
          onSuccess: function(transport) {
            var results    = transport.responseJSON;
@@ -731,113 +729,17 @@ var GBrowseController = Class.create({
       return false; 
     }
     else if (plugin_type == 'finder'){
-        alert("Not Implemented Yet");
+        alert('Searching for ' + $F('landmark_search_field') + ' via ' + $F('plugin'));
+	document.searchform.plugin_find.value  = $F('plugin');
+	document.searchform.force_submit.value = 1;
+	document.searchform.submit();
     }
   }, // end plugin_go
 
-  // Upload File Methods *************************************************
-
-  edit_new_file:
-  function() {
-    Controller.update_sections(new Array(external_utility_div_id), '&new_edit_file=1',true,true);
-  },
-
-  edit_upload:
-  function(edit_file) {
-    var gbtrack  = this.gbtracks.get(decodeURIComponent(edit_file));
-    var basename = gbtrack!=null ? gbtrack.track_name : edit_file;
-    visibility('upload_tracks_panel',1);
-    Controller.update_sections(new Array(external_utility_div_id), 
-   	    '&edit_file='+basename,true,true);
-  },
-
-  commit_file_edit:
-  function(edited_file) {
-    var form_element = $(edit_upload_form_id);
-    new Ajax.Request(document.URL,{
-      method:     'post',
-      parameters: form_element.serialize() +"&"+ $H({
-            action:      'commit_file_edit',
-            edited_file: edited_file
-          }).toQueryString(),
-      onSuccess: function(transport) {
-        var results      = transport.responseJSON;
-        var file_created = results.file_created;
-	var tracks       = results.tracks;
-	var error        = results.error;
-	
-	if (error) {
-           alert(error);
-           return; 
-        }        
-
-        Controller.wipe_div(external_utility_div_id); 
-
-	var current_tracks = new Hash();
-	Controller.each_track(edited_file,function(gbtrack){
-           current_tracks.set(gbtrack.track_id,gbtrack);
-	});
-
-	var new_tracks = new Hash();
-	tracks.each(function(trackid){
-           new_tracks.set(trackid,1);
-	});
-
-	var tracks_to_delete = current_tracks.keys().findAll(function(trackid) {
-            return new_tracks.get(trackid)==null;
-	});
-	var tracks_to_add    = new_tracks.keys().findAll(function(trackid) {
-	    return current_tracks.get(trackid)==null;
-	});
-	var tracks_to_update = new_tracks.keys().findAll(function(trackid) {
-	    return current_tracks.get(trackid)!= null;
-	});
-
-	tracks_to_update.each(function(id) { 
-	   Controller.rerender_track(id,true);
-	   Controller.update_sections(new Array(external_listing_id),null,null,true);
-	});
-
-	tracks_to_delete.each(function(id) { 
-	   var gbtrack = current_tracks.get(id);
-	   actually_remove(gbtrack.track_div_id);
-	   Controller.unregister_gbtrack(gbtrack);
-	   Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,false);
-	});
-
-	if (tracks_to_add.length > 0)
-          Controller.add_track(edited_file, function(){
-            Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,false);
-        },true);	
-
-      } // end onSuccess
-    });
-  },
-
-  delete_upload_file:
-  function(file_name) {
-
-    $(external_listing_id).innerHTML='<p><b style="background-color:yellow">Working...</b></p>';
-
-    new Ajax.Request(document.URL,{
-      method:     'post',
-      parameters: {
-        action: 'delete_upload_file',
-	file:   file_name
-      },
-      onSuccess: function(transport) {
-        Controller.each_track(file_name,function(gbtrack) {
-	      actually_remove(gbtrack.track_div_id);
-          });
-        Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,true);
-        Controller.unregister_track(file_name);
-      } // end onSuccess
-    });
-  },
-
   cancel_upload:
-  function(upload_id) {
-       new Ajax.Request(document.URL,{
+  function(destination,upload_id) {
+       new Ajax.Updater(destination,
+                        document.URL,{
               method:    'post',
               parameters: {
                               action: 'cancel_upload',
@@ -846,35 +748,6 @@ var GBrowseController = Class.create({
         });
   },
 
-  // Remote Annotations Methods *************************************************
-
-  new_remote_track:
-  function(eurl) {
-    if ( eurl == '') return;
-
-    $(external_listing_id).innerHTML='<p><b style="background-color:yellow">Working...</b></p>';
-
-    new Ajax.Request(document.URL,{
-      method:     'post',
-      parameters:{
-            action: 'add_url',
-            eurl:    eurl
-      },
-      onSuccess: function(transport) {
-        var results     = transport.responseJSON;
-        var url_created = results.url_created;
-        if ( 1 == url_created ){
-          Controller.add_track(eurl, function(){
-            Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,true);
-          })
-        } else
-	  Controller.each_track(eurl,function(gbtrack) {
-             Controller.rerender_track(gbtrack.track_id,true);
-          });
-        }
-    });
-  },
-
   // Utility methods *********************************
   show_error:
   function (message,details) {
@@ -1010,11 +883,10 @@ var GBrowseController = Class.create({
 	      startAjaxUpload(upload_id);
 	     },
          onSuccess:   function (transport) {
-//	 	          if ($(editElement) != null) $(editElement).innerHTML = '';
 	 	          if ($(editElement) != null) $(editElement).remove();
 			  var r = transport.responseJSON;
 			  r.tracks.each(function(t) {
-			  	      Controller.rerender_track(t);
+			  	      Controller.rerender_track(t,true,true);
 				      });
 		          var updater = Ajax_Status_Updater.get(upload_id);
 			  if (updater != null) updater.stop();
